@echo off
REM Detecting your OS for correct SoX installation path
REM This assumes you're installing it on Program Files and using default path that the installer provided
REM But, if you're using different folder name while also still install it on the Program Files, change the SoX default directory name to what you used to install it below.
reg Query "HKLM\Hardware\Description\System\CentralProcessor\0" | find /i "x86" > NUL && set OPSYS=32BIT || set OPSYS=64BIT
if %OPSYS%==32BIT set SOX_PATH="%ProgramFiles%\sox-14-4-2"
if %OPSYS%==64BIT set SOX_PATH="%ProgramFiles(x86)%\sox-14-4-2"

REM Also, if you installed it outside of Program Files, comment those lines above and then uncomment this line below and change it accordingly.
REM set SOX_PATH=[INSERT_YOUR_CUSTOM_SOX_INSTALLATION_PATH_HERE]

REM Insert your MP3 folder path in the "AUDPATH" field below
set AUDPATH=

REM Insert your converted audio output directory in this field below. By default, it's set to "songs" directory
set outputdir=songs

if NOT EXIST %SOX_PATH% (
	echo SoX install not detected! You have to install SoX for this tool to run!
	pause
	exit
) else if NOT EXIST quickbms.exe (
	echo QuickBMS not found! You have to put it on the same directory as this tool to run!
	pause
	exit
) else if NOT EXIST VAG2THAWKPS2.bms (
	echo Audio conversion script not found! You have to put it on the same directory as this tool to run!
	pause
	exit
) else (
	goto VAGConverterCheck
)

:VAGConverterCheck
if EXIST vagpack.exe (
	if EXIST AIFF2VAG.exe (
		echo Multiple VAG converters detected!
		echo.
		echo Choose your VAG conversion method
		echo 1. vagpack
		echo 2. AIFF2VAG
		echo.
		choice /c 12 /m "Which one you want to choose"
		if errorlevel 2 goto StartConversionAIFF2VAG
		if errorlevel 1 goto StartConversionvagpack
	)
) else if EXIST vagpack.exe (
	if NOT EXIST AIFF2VAG.exe (
		goto StartConversionvagpack
	)
) else if EXIST AIFF2VAG.exe (
	if NOT EXIST vagpack.exe (
		goto StartConversionAIFF2VAG
	)
) else (
	echo vagpack or AIFF2VAG not found! You have to put it on the same directory as this tool to run!
	pause
	exit
)


:StartConversionvagpack
cls
echo.
echo THPS audio conversion batch tool (for PS2)
echo By BloodRaynare/RazorHack5000
echo.
echo Please wait while this tool converts all of your audio
echo.
echo vagpack is detected/used
for %%i in ("%AUDPATH%\*.mp3") do (
	echo.
	echo Converting your MP3 to separate channel .wav files....
	echo.
	IF NOT EXIST splitTMP mkdir splitTMP
	%SOX_PATH%\sox "%%~fnxi" -q -V1 -D -c 1 -r 48000 "splitTMP\%%~ni_L.wav" remix 1
	%SOX_PATH%\sox "%%~fnxi" -q -V1 -D -c 1 -r 48000 "splitTMP\%%~ni_R.wav" remix 2
	echo.
	echo Converting those .wav's to .vag...
	echo.
	vagpack "splitTMP\%%~ni_L.wav"
	vagpack "splitTMP\%%~ni_R.wav"
	echo.
	echo Combine those separate vag files into headerless stereo PS2 ADPCM audio...
	echo.
	IF NOT EXIST "%outputdir%" mkdir "%outputdir%"
	quickbms -o VAG2THAWKPS2.bms ".\splitTMP\%%~ni_L.vag" "%outputdir%"
	echo.
	echo Deleting temporary files...
	echo.
	del "splitTMP\%%~ni_L.wav"
	del "splitTMP\%%~ni_R.wav"
	del "splitTMP\%%~ni_L.vag"
	del "splitTMP\%%~ni_R.vag"
)
echo.
echo Deleting temporary directories
echo.
rmdir splitTMP
goto ConversionDone

:StartConversionAIFF2VAG
cls
echo.
echo THPS audio conversion batch tool (for PS2)
echo By BloodRaynare/RazorHack5000
echo.
echo Please wait while this tool converts all of your audio
echo.
echo AIFF2VAG is detected/used
for %%i in ("%AUDPATH%\*.mp3") do (
	echo.
	echo Converting your MP3 to separate channel .aif files....
	echo.
	IF NOT EXIST splitTMP mkdir splitTMP
	%SOX_PATH%\sox "%%~fnxi" -q -V1 -D -c 1 -r 48000 "splitTMP\%%~ni_L.aif" remix 1
	%SOX_PATH%\sox "%%~fnxi" -q -V1 -D -c 1 -r 48000 "splitTMP\%%~ni_R.aif" remix 2
	echo.
	echo Converting those .aif's to .vag...
	echo.
	AIFF2VAG "splitTMP\%%~ni_L.aif"
	AIFF2VAG "splitTMP\%%~ni_R.aif"
	echo.
	echo Combine those separate vag files into headerless stereo PS2 ADPCM audio...
	echo.
	IF NOT EXIST "%outputdir%" mkdir "%outputdir%"
	quickbms -o VAG2THAWKPS2.bms ".\splitTMP\%%~ni_L.vag" "%outputdir%"
	echo.
	echo Deleting temporary files...
	echo.
	del "splitTMP\%%~ni_L.aif"
	del "splitTMP\%%~ni_R.aif"
	del "splitTMP\%%~ni_L.vag"
	del "splitTMP\%%~ni_R.vag"
)
echo.
echo Deleting temporary directories
echo.
rmdir splitTMP
goto ConversionDone

:ConversionDone
echo.
echo Conversion done. Press ENTER to exit
pause >nul
